@@ -32,4 +32,8 @@ Run m1key -h to know what you can do...""")
 def main():
     path =  inspect.getfile(requests)[:-20]+"m1key/profile.txt"
     f = open(path,"r")
-    print(f.read())
\ No newline at end of file
+    print(f.read())
+    print("""Hello, it's Mithilesh Tiwari , aka m1key. Welcome to m1key world.
+I am currently pursuing B.Tech from Motilal Nehru National Institute of Technology 
+in Information Technology. I am currently in 6th semester.\nSince I got bore in this covid period, so I decided to made this package. I hope you will enjoy :) 
+Run m1key -h or m1key -c to know more what you can do""")
\ No newline at end of file
